==> ejc-procurement-api-3.0.0-20251216.074156-136-sources.jar: com/ejianc/business/procurement/perform/vo/ProjectExceptionVO.java <==
package com.ejianc.business.procurement.perform.vo;

import java.util.Date;
import java.math.*;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 采购项目异常
 * 
 * @author generator
 * 
 */
public class ProjectExceptionVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String exceptionType; // 异常类型：流标、废标、异议、投诉、其他原因终止
    private Date applyDate; // 异常申报时间
    private String applyOrgName; // 异常申报单位名称
    private Long applyOrgId; // 异常申报单位id
    private Integer businessState; // 解决措施：2取消采购；3暂停采购；4重新采购
    private Integer nobidMethod; // 非招标交易方式
    private String memo; // 异常情况说明
    private Date makeDate; // 编制日期
    private String employeeName; // 经办人名称
    private Long employeeId; // 经办人
    private BigDecimal budgetTaxMny; // 采购预算
    private String projectCode; // 采购项目编码
    private Integer publishType; // 采购公开程度：公开、邀请
    private Long projectId; // 采购项目id
    private String planObject; // 采购标的
    private String projectName; // 采购项目名称
    private String executePlanName; // 执行计划名称
    private String executePlanCode; // 执行计划编码
    private Long executePlanId; // 执行计划
    private String businessType; // 标的物类别1-工程，2-货物，3-服务
    private Integer organizeShape; // 采购组织形式1-自主采购,2-委托采购
    private Integer permissionType; // 实施权限1-一级集采，2-二级集采，3-所属单位，4-项目经理部
    private String performWay; // 采购实施方式1-招标，2-非招标
    private String orgCode; // 采购实施单位编码
    private String orgName; // 采购实施单位名称
    private Long orgId; // 采购实施单位Id
    private String billCode; // 单据编号
    private Integer billState; // 单据状态
    

    public String getExceptionType() {
        return exceptionType;
    }

    public void setExceptionType(String exceptionType) {
        this.exceptionType = exceptionType;
    }
    public Date getApplyDate() {
        return applyDate;
    }

    public void setApplyDate(Date applyDate) {
        this.applyDate = applyDate;
    }
    public String getApplyOrgName() {
        return applyOrgName;
    }

    public void setApplyOrgName(String applyOrgName) {
        this.applyOrgName = applyOrgName;
    }
    public Long getApplyOrgId() {
        return applyOrgId;
    }

    public void setApplyOrgId(Long applyOrgId) {
        this.applyOrgId = applyOrgId;
    }
    public Integer getBusinessState() {
        return businessState;
    }

    public void setBusinessState(Integer businessState) {
        this.businessState = businessState;
    }
    public Integer getNobidMethod() {
        return nobidMethod;
    }

    public void setNobidMethod(Integer nobidMethod) {
        this.nobidMethod = nobidMethod;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getMakeDate() {
        return makeDate;
    }

    public void setMakeDate(Date makeDate) {
        this.makeDate = makeDate;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public BigDecimal getBudgetTaxMny() {
        return budgetTaxMny;
    }

    public void setBudgetTaxMny(BigDecimal budgetTaxMny) {
        this.budgetTaxMny = budgetTaxMny;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Integer getPublishType() {
        return publishType;
    }

    public void setPublishType(Integer publishType) {
        this.publishType = publishType;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getPlanObject() {
        return planObject;
    }

    public void setPlanObject(String planObject) {
        this.planObject = planObject;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getExecutePlanName() {
        return executePlanName;
    }

    public void setExecutePlanName(String executePlanName) {
        this.executePlanName = executePlanName;
    }
    public String getExecutePlanCode() {
        return executePlanCode;
    }

    public void setExecutePlanCode(String executePlanCode) {
        this.executePlanCode = executePlanCode;
    }
    public Long getExecutePlanId() {
        return executePlanId;
    }

    public void setExecutePlanId(Long executePlanId) {
        this.executePlanId = executePlanId;
    }
    public String getBusinessType() {
        return businessType;
    }

    public void setBusinessType(String businessType) {
        this.businessType = businessType;
    }
    public Integer getOrganizeShape() {
        return organizeShape;
    }

    public void setOrganizeShape(Integer organizeShape) {
        this.organizeShape = organizeShape;
    }
    public Integer getPermissionType() {
        return permissionType;
    }

    public void setPermissionType(Integer permissionType) {
        this.permissionType = permissionType;
    }
    public String getPerformWay() {
        return performWay;
    }

    public void setPerformWay(String performWay) {
        this.performWay = performWay;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
}

==> ejc-procurement-api-3.0.0-20251217.021048-143-sources.jar: com/ejianc/business/procurement/perform/vo/ProjectExceptionVO.java <==
package com.ejianc.business.procurement.perform.vo;

import java.util.Date;
import java.math.*;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 采购项目异常
 * 
 * @author generator
 * 
 */
public class ProjectExceptionVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String exceptionType; // 异常类型：流标、废标、异议、投诉、其他原因终止
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date applyDate; // 异常申报时间
    private String applyOrgName; // 异常申报单位名称
    private Long applyOrgId; // 异常申报单位id
    private Integer businessState; // 解决措施：2取消采购；3暂停采购；4重新采购
    private Integer nobidMethod; // 非招标交易方式
    private String memo; // 异常情况说明
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date makeDate; // 编制日期
    private String employeeName; // 经办人名称
    private Long employeeId; // 经办人
    private BigDecimal budgetTaxMny; // 采购预算
    private String projectCode; // 采购项目编码
    private Integer publishType; // 采购公开程度：公开、邀请
    private Long projectId; // 采购项目id
    private String planObject; // 采购标的
    private String projectName; // 采购项目名称
    private String executePlanName; // 执行计划名称
    private String executePlanCode; // 执行计划编码
    private Long executePlanId; // 执行计划
    private String businessType; // 标的物类别1-工程，2-货物，3-服务
    private Integer organizeShape; // 采购组织形式1-自主采购,2-委托采购
    private Integer permissionType; // 实施权限1-一级集采，2-二级集采，3-所属单位，4-项目经理部
    private String performWay; // 采购实施方式1-招标，2-非招标
    private String orgCode; // 采购实施单位编码
    private String orgName; // 采购实施单位名称
    private Long orgId; // 采购实施单位Id
    private String billCode; // 单据编号
    private Integer billState; // 单据状态
    

    public String getExceptionType() {
        return exceptionType;
    }

    public void setExceptionType(String exceptionType) {
        this.exceptionType = exceptionType;
    }
    public Date getApplyDate() {
        return applyDate;
    }

    public void setApplyDate(Date applyDate) {
        this.applyDate = applyDate;
    }
    public String getApplyOrgName() {
        return applyOrgName;
    }

    public void setApplyOrgName(String applyOrgName) {
        this.applyOrgName = applyOrgName;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getApplyOrgId() {
        return applyOrgId;
    }
    @ReferDeserialTransfer
    public void setApplyOrgId(Long applyOrgId) {
        this.applyOrgId = applyOrgId;
    }
    public Integer getBusinessState() {
        return businessState;
    }

    public void setBusinessState(Integer businessState) {
        this.businessState = businessState;
    }
    public Integer getNobidMethod() {
        return nobidMethod;
    }

    public void setNobidMethod(Integer nobidMethod) {
        this.nobidMethod = nobidMethod;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getMakeDate() {
        return makeDate;
    }

    public void setMakeDate(Date makeDate) {
        this.makeDate = makeDate;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public BigDecimal getBudgetTaxMny() {
        return budgetTaxMny;
    }

    public void setBudgetTaxMny(BigDecimal budgetTaxMny) {
        this.budgetTaxMny = budgetTaxMny;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Integer getPublishType() {
        return publishType;
    }

    public void setPublishType(Integer publishType) {
        this.publishType = publishType;
    }
    @ReferSerialTransfer(referCode = "procurement-purchase-project")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getPlanObject() {
        return planObject;
    }

    public void setPlanObject(String planObject) {
        this.planObject = planObject;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getExecutePlanName() {
        return executePlanName;
    }

    public void setExecutePlanName(String executePlanName) {
        this.executePlanName = executePlanName;
    }
    public String getExecutePlanCode() {
        return executePlanCode;
    }

    public void setExecutePlanCode(String executePlanCode) {
        this.executePlanCode = executePlanCode;
    }
    @ReferSerialTransfer(referCode = "ejc_procurement_execute_plan")
    public Long getExecutePlanId() {
        return executePlanId;
    }
    @ReferDeserialTransfer
    public void setExecutePlanId(Long executePlanId) {
        this.executePlanId = executePlanId;
    }
    public String getBusinessType() {
        return businessType;
    }

    public void setBusinessType(String businessType) {
        this.businessType = businessType;
    }
    public Integer getOrganizeShape() {
        return organizeShape;
    }

    public void setOrganizeShape(Integer organizeShape) {
        this.organizeShape = organizeShape;
    }
    public Integer getPermissionType() {
        return permissionType;
    }

    public void setPermissionType(Integer permissionType) {
        this.permissionType = permissionType;
    }
    public String getPerformWay() {
        return performWay;
    }

    public void setPerformWay(String performWay) {
        this.performWay = performWay;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
}
